==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/request/WorkflowbinaryRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Workflowbinary;
import microsoft.dynamics.crm.entity.collection.request.AsyncoperationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.BulkdeletefailureCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.FileattachmentCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.MailboxtrackingfolderCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.PrincipalobjectattributeaccessCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.ProcesssessionCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

@JsonIgnoreType
public class WorkflowbinaryRequest extends EntityRequest<Workflowbinary> {

    public WorkflowbinaryRequest(ContextPath contextPath, Optional<Object> value) {
        super(Workflowbinary.class, contextPath, SchemaInfo.INSTANCE, value);
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public SystemuserRequest owninguser() {
        return new SystemuserRequest(contextPath.addSegment("owninguser"), Optional.empty());
    }

    public TeamRequest owningteam() {
        return new TeamRequest(contextPath.addSegment("owningteam"), Optional.empty());
    }

    public PrincipalRequest ownerid() {
        return new PrincipalRequest(contextPath.addSegment("ownerid"), Optional.empty());
    }

    public BusinessunitRequest owningbusinessunit() {
        return new BusinessunitRequest(contextPath.addSegment("owningbusinessunit"), Optional.empty());
    }

    public SyncerrorCollectionRequest workflowbinary_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("workflowbinary_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest workflowbinary_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("workflowbinary_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest workflowbinary_AsyncOperations() {
        return new AsyncoperationCollectionRequest(
                        contextPath.addSegment("workflowbinary_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest workflowbinary_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("workflowbinary_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest workflowbinary_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(
                        contextPath.addSegment("workflowbinary_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest workflowbinary_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("workflowbinary_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest workflowbinary_ProcessSession() {
        return new ProcesssessionCollectionRequest(
                        contextPath.addSegment("workflowbinary_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest workflowbinary_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("workflowbinary_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest workflowbinary_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(
                        contextPath.addSegment("workflowbinary_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest workflowbinary_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("workflowbinary_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest workflowbinary_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(
                        contextPath.addSegment("workflowbinary_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest workflowbinary_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("workflowbinary_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public FileattachmentCollectionRequest workflowbinary_FileAttachments() {
        return new FileattachmentCollectionRequest(
                        contextPath.addSegment("workflowbinary_FileAttachments"), Optional.empty());
    }

    public FileattachmentRequest workflowbinary_FileAttachments(String fileattachmentid) {
        return new FileattachmentRequest(contextPath.addSegment("workflowbinary_FileAttachments").addKeys(new NameValue(fileattachmentid.toString())), Optional.empty());
    }

    public FlowsessionRequest flowSessionId() {
        return new FlowsessionRequest(contextPath.addSegment("FlowSessionId"), Optional.empty());
    }

    public WorkflowRequest process() {
        return new WorkflowRequest(contextPath.addSegment("Process"), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.49-sources.jar: microsoft/dynamics/crm/entity/request/WorkflowbinaryRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Workflowbinary;
import microsoft.dynamics.crm.entity.collection.request.AsyncoperationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.BulkdeletefailureCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.FileattachmentCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.MailboxtrackingfolderCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.PrincipalobjectattributeaccessCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.ProcesssessionCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;

@JsonIgnoreType
public class WorkflowbinaryRequest extends EntityRequest<Workflowbinary> {

    public WorkflowbinaryRequest(ContextPath contextPath, Optional<Object> value) {
        super(Workflowbinary.class, contextPath, value);
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public SystemuserRequest owninguser() {
        return new SystemuserRequest(contextPath.addSegment("owninguser"), Optional.empty());
    }

    public TeamRequest owningteam() {
        return new TeamRequest(contextPath.addSegment("owningteam"), Optional.empty());
    }

    public PrincipalRequest ownerid() {
        return new PrincipalRequest(contextPath.addSegment("ownerid"), Optional.empty());
    }

    public BusinessunitRequest owningbusinessunit() {
        return new BusinessunitRequest(contextPath.addSegment("owningbusinessunit"), Optional.empty());
    }

    public SyncerrorCollectionRequest workflowbinary_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("workflowbinary_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest workflowbinary_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("workflowbinary_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest workflowbinary_AsyncOperations() {
        return new AsyncoperationCollectionRequest(
                        contextPath.addSegment("workflowbinary_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest workflowbinary_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("workflowbinary_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest workflowbinary_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(
                        contextPath.addSegment("workflowbinary_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest workflowbinary_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("workflowbinary_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest workflowbinary_ProcessSession() {
        return new ProcesssessionCollectionRequest(
                        contextPath.addSegment("workflowbinary_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest workflowbinary_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("workflowbinary_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest workflowbinary_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(
                        contextPath.addSegment("workflowbinary_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest workflowbinary_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("workflowbinary_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest workflowbinary_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(
                        contextPath.addSegment("workflowbinary_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest workflowbinary_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("workflowbinary_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public FileattachmentCollectionRequest workflowbinary_FileAttachments() {
        return new FileattachmentCollectionRequest(
                        contextPath.addSegment("workflowbinary_FileAttachments"), Optional.empty());
    }

    public FileattachmentRequest workflowbinary_FileAttachments(String fileattachmentid) {
        return new FileattachmentRequest(contextPath.addSegment("workflowbinary_FileAttachments").addKeys(new NameValue(fileattachmentid.toString())), Optional.empty());
    }

    public FlowsessionRequest flowSessionId() {
        return new FlowsessionRequest(contextPath.addSegment("FlowSessionId"), Optional.empty());
    }

    public WorkflowRequest process() {
        return new WorkflowRequest(contextPath.addSegment("Process"), Optional.empty());
    }

}
